{% extends 'lib/base.html' %}
{% block body %}
{% include "lib/summary_facts.html" %}
<div class="row">
    <div class="col-sm-12">
        {% include 'plotting/plot_history.html' %}
    </div>
</div>
<div class="row">
    <div class="col-sm-4">
        {% include 'plotting/plot_pie_chart.html' %}
    </div>
    <div class="col-sm-8">
        {% include 'plotting/plot_trend.html' %}
    </div>
</div>
{% include 'lib/table.html' %}
{% endblock %}