var greenIcon = new L.Icon({
    iconUrl: 'https://cdn.rawgit.com/pointhi/leaflet-color-markers/master/img/marker-icon-green.png',
    iconSize: [18, 28],
    iconAnchor: [9, 28],
    popupAnchor: [1, -34],
});

var redIcon = new L.Icon({
    iconUrl: 'https://cdn.rawgit.com/pointhi/leaflet-color-markers/master/img/marker-icon-red.png',
    iconSize: [18, 28],
    iconAnchor: [9, 28],
    popupAnchor: [1, -34],
});