# Generated by Django 3.1.6 on 2021-03-03 05:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("wkz", "0003_auto_20210218_2232"),
    ]

    operations = [
        migrations.AddField(
            model_name="settings",
            name="path_to_activities_on_device",
            field=models.CharField(
                default="/Primary/GARMIN/Activity/",
                max_length=120,
                verbose_name="Path to Activities Folder on Garmin Device:",
            ),
        ),
    ]
