# Generated by Django 3.1.6 on 2021-03-21 17:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("wkz", "0005_remove_settings_path_to_activities_on_device"),
    ]

    operations = [
        migrations.RenameField(
            model_name="bestsection",
            old_name="section_distance",
            new_name="distance",
        ),
        migrations.RenameField(
            model_name="bestsection",
            old_name="end_index",
            new_name="end",
        ),
        migrations.RenameField(
            model_name="bestsection",
            old_name="section_type",
            new_name="kind",
        ),
        migrations.RenameField(
            model_name="bestsection",
            old_name="start_index",
            new_name="start",
        ),
        migrations.AlterField(
            model_name="settings",
            name="number_of_days",
            field=models.IntegerField(
                choices=[
                    (9999, "all"),
                    (1095, "3 years"),
                    (730, "2 years"),
                    (365, "1 year"),
                    (180, "180 days"),
                    (90, "90 days"),
                    (30, "30 days"),
                    (10, "10 days"),
                ],
                default=30,
            ),
        ),
    ]
