# Generated by Django 3.1.6 on 2021-03-14 18:12

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("wkz", "0004_settings_path_to_activities_on_device"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="settings",
            name="path_to_activities_on_device",
        ),
    ]
