lines_colors = [
    "Red",
    "DodgerBlue",
    "LimeGreen",
    "Gold",
    "MediumSlateBlue",
    "Brown",
    "Olive",
    "Orange",
    "DarkGoldenRod",
    "Salmon",
    "Fuchsia",
    "Aqua",
    "LightSlateGray",
    "MediumBlue",
    "GreenYellow",
    "DarkRed",
    "DarkMagenta",
    "Khaki",
    "MediumSpringGreen",
    "OrangeRed",
    "DarkGreen",
    "LightPink",
    "DarkSlateBlue",
    "Yellow",
    "Turquoise",
    "SaddleBrown",
    "Maroon",
    "Ivory",
    "SpringGreen",
    "BlueViolet",
    "Coral",
    "Teal",
    "Navy",
    "LightGoldenRodYellow",
    "DarkOliveGreen",
    "Coral",
    "Red",
    "DodgerBlue",
    "LimeGreen",
    "Gold",
    "MediumSlateBlue",
    "Brown",
    "Olive",
    "Orange",
    "DarkGoldenRod",
    "Salmon",
    "Fuchsia",
    "Aqua",
    "LightSlateGray",
    "MediumBlue",
    "GreenYellow",
    "DarkRed",
    "DarkMagenta",
    "Khaki",
    "MediumSpringGreen",
    "OrangeRed",
    "DarkGreen",
    "LightPink",
    "DarkSlateBlue",
    "Yellow",
    "Turquoise",
    "SaddleBrown",
    "Maroon",
    "Ivory",
    "SpringGreen",
    "BlueViolet",
    "Coral",
    "Teal",
    "Navy",
    "LightGoldenRodYellow",
    "DarkOliveGreen",
    "Coral",
    "Red",
    "DodgerBlue",
    "LimeGreen",
    "Gold",
    "MediumSlateBlue",
    "Brown",
    "Olive",
    "Orange",
    "DarkGoldenRod",
    "Salmon",
    "Fuchsia",
    "Aqua",
    "LightSlateGray",
    "MediumBlue",
    "GreenYellow",
    "DarkRed",
    "DarkMagenta",
    "Khaki",
    "MediumSpringGreen",
    "OrangeRed",
    "DarkGreen",
    "LightPink",
    "DarkSlateBlue",
    "Yellow",
    "Turquoise",
    "SaddleBrown",
    "Maroon",
    "Ivory",
    "SpringGreen",
    "BlueViolet",
    "Coral",
    "Teal",
    "Navy",
    "LightGoldenRodYellow",
    "DarkOliveGreen",
    "Coral",
    "Red",
    "DodgerBlue",
    "LimeGreen",
    "Gold",
    "MediumSlateBlue",
    "Brown",
    "Olive",
    "Orange",
    "DarkGoldenRod",
    "Salmon",
    "Fuchsia",
    "Aqua",
    "LightSlateGray",
    "MediumBlue",
    "GreenYellow",
    "DarkRed",
    "DarkMagenta",
    "Khaki",
    "MediumSpringGreen",
    "OrangeRed",
    "DarkGreen",
    "LightPink",
    "DarkSlateBlue",
    "Yellow",
    "Turquoise",
    "SaddleBrown",
    "Maroon",
    "Ivory",
    "SpringGreen",
    "BlueViolet",
    "Coral",
    "Teal",
    "Navy",
    "LightGoldenRodYellow",
    "DarkOliveGreen",
    "Coral",
    "Red",
    "DodgerBlue",
    "LimeGreen",
    "Gold",
    "MediumSlateBlue",
    "Brown",
    "Olive",
    "Orange",
    "DarkGoldenRod",
    "Salmon",
    "Fuchsia",
    "Aqua",
    "LightSlateGray",
    "MediumBlue",
    "GreenYellow",
    "DarkRed",
    "DarkMagenta",
    "Khaki",
    "MediumSpringGreen",
    "OrangeRed",
    "DarkGreen",
    "LightPink",
    "DarkSlateBlue",
    "Yellow",
    "Turquoise",
    "SaddleBrown",
    "Maroon",
    "Ivory",
    "SpringGreen",
    "BlueViolet",
    "Coral",
    "Teal",
    "Navy",
    "LightGoldenRodYellow",
    "DarkOliveGreen",
    "Coral",
]
