# Generated by Django 3.2 on 2021-06-11 05:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("wkz", "0007_auto_20210430_1633"),
    ]

    operations = [
        migrations.AddField(
            model_name="traces",
            name="total_ascent",
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="traces",
            name="total_descent",
            field=models.IntegerField(blank=True, null=True),
        ),
    ]
