{% include "plotting/bokeh_statics.html" %}

<div class="card">
    <div class="card-body">
        {{ script_time_series | safe }}
        {% if div_time_series %}
            {{ div_time_series | safe }}
        {% endif %}
    </div>
</div>
