{% if section.pk == top_award.pk %}
    {% if top_award.rank == 1 %}
        <i class="fas fa-trophy" data-toggle="tooltip" data-placement="bottom" title="1st Place in this Section"
            style="color: gold;"></i>
    {% elif top_award.rank == 2 %}
        <i class="fas fa-trophy" data-toggle="tooltip" data-placement="bottom" title="2nd Place in this Section"
            style="color: silver;"></i>
    {% elif top_award.rank == 3 %}
        <i class="fas fa-trophy" data-toggle="tooltip" data-placement="bottom" title="3rd Place in this Section"
            style="color: burlywood;"></i>
    {% endif %}
{% endif %}