<footer class="footer footer-black footer-white ">
    <div class="container-fluid">
        <div class="row">
            <nav class="footer-nav">
                <ul>
                    <li><a href="https://github.com/fgebhart/workoutizer" target="_blank"><i class="fab fa-github"></i></a></li>
                    <li><a href="https://github.com/fgebhart/workoutizer/issues" target="_blank">Report an Issue</a></li>
                </ul>
            </nav>
            {% if page_name == "Settings" or page_name == "Help" %}
                <div class="credits ml-auto">
                    <span class="copyright">
                        © <script>
                            document.write(new Date().getFullYear())
                        </script>, made with <i class="fa fa-heart heart"></i> by <a class="simple-text" href="https://github.com/fgebhart">Fabian Gebhart</a>
                    </span>
                </div>
            {% endif %}
        </div>
    </div>
</footer>
