{% extends 'lib/base.html' %}
{% block body %}
<div class="row">
    <div class="col-md-8">
        {% include "lib/keymap.html" %}
        <div class="card">
            <div class="card-header">
                <h4 class="card-title">Source Code</h4>
            </div>
            <div class="card-body">
                <p>
                    The Workoutizer source code can be found on:
                </p>
                <ul>
                    <li>
                    <a href="https://github.com/fgebhart/workoutizer">https://github.com/fgebhart/workoutizer</a>
                    </li>
                </ul>
                <p>
                    Feel free to get in touch to contribute or open an <a href="https://github.com/fgebhart/workoutizer/issues">issue</a>.
                </p>
            </div>
        </div>
    </div>
    <div class="col-md-4">
        <div class="card">
            <div class="card-header">
                <h4 class="card-title">Version</h4>
            </div>
            <div class="card-body">
                <p>
                    You are running: <span class="badge badge-pill badge-default">{{ version }}</span>
                </p>
                <p>
                    Have a look at the <a href="https://github.com/fgebhart/workoutizer/releases">release page</a>
                    for the recent releases.
                </p>
            </div>
        </div>
    </div>
</div>
{% endblock %}
