<div class="card">
    <div class="card-header">
        <h4 class="card-title">Keyboard Navigation</h4>
    </div>
    <div class="card-body">
        <p>Use the following keyboard shortcuts to navigate through Workoutizer:</p>
        <table class="table table-hover" hx-indicator=".htmx-indicator">
            <tbody>
                <tr>
                    <td><u>G</u>o to <u>D</u>ashboard</td><td><kbd>g</kbd> + <kbd>d</kbd></td>
                </tr>
                <tr>
                    <td><u>G</u>o to all <u>S</u>ports</td><td><kbd>g</kbd> + <kbd>s</kbd></td>
                </tr>
                <tr>
                    <td><u>G</u>o to <u>A</u>wards</td><td><kbd>g</kbd> + <kbd>a</kbd></td>
                </tr>
                <tr>
                    <td><u>G</u>o to Sport</td><td><kbd>g</kbd> + <kbd>Number</kbd></td>
                </tr>
                <tr>
                    <td><u>G</u>o to <u>e</u>dit Sport/Activity</td><td><kbd>g</kbd> + <kbd>e</kbd></td>
                </tr>
                <tr>
                    <td><u>G</u>o to Settings</td><td><kbd>g</kbd> + <kbd>,</kbd></td>
                </tr>
                <tr>
                    <td><u>G</u>o to <u>H</u>elp</td><td><kbd>g</kbd> + <kbd>h</kbd></td>
                </tr>
                <tr>
                    <td><u>G</u>o to add Activity</td><td><kbd>g</kbd> + <kbd>n</kbd></td>
                </tr>
                <tr>
                    <td>Toggle Sidebar</td><td><kbd>[</kbd></td>
                </tr>
            </tbody>
        </table>
    </div>
</div>
