{% extends 'lib/base.html' %}
{% load static %}
{% block body %}
<div class="row">
    <div class="col-md-10 ml-auto mr-auto">
        <div class="card card-plain card-subcategories">
            <div class="card-body ">
                <ul class="nav nav-pills nav-pills-default nav-pills-icons justify-content-center" role="tablist">
                    <li class="nav-item">
                        <a class="nav-link active" data-toggle="tab" href="#fastest" role="tablist">
                            <i class="fas fa-tachometer-alt"></i>
                            &nbsp;Fastest Section
                        </a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" data-toggle="tab" href="#climb" role="tablist">
                            <i class="fas fa-mountain"></i>
                            &nbsp;Best Climb Section
                        </a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" data-toggle="tab" href="#ascent" role="tablist">
                            <i class="fas fa-arrow-up"></i>
                            &nbsp;Total Ascent
                        </a>
                    </li>
                </ul>
                <div class="tab-content tab-space tab-subcategories">
                    <div id="fastest" class="container tab-pane active"><br>
                        {% for sport, top_award in top_fastest_awards.items %}
                            <div class="card">
                                <div class="card-header">
                                    <h4 class="card-title">{{ sport }}&nbsp;&nbsp;<a href="/sport/{{ sport.slug }}"><i class="fas fa-{{ sport.icon }}" style="color: {{ sport.color }};"></i></a></h4>
                                </div>
                                <div class="card-body">
                                    <div class="table-responsive">
                                        {% include "awards/velocity_table.html" %}
                                    </div>
                                </div>
                            </div>
                        {% endfor %}
                    </div>
                    <div id="climb" class="container tab-pane fade"><br>
                        {% for sport, top_award in top_climb_awards.items %}
                            <div class="card">
                                <div class="card-header">
                                    <h4 class="card-title">{{ sport }}&nbsp;&nbsp;<a href="/sport/{{ sport.slug }}"><i class="fas fa-{{ sport.icon }}" style="color: {{ sport.color }};"></i></a></h4>
                                </div>
                                <div class="card-body">
                                    <div class="table-responsive">
                                        {% include "awards/climb_table.html" %}
                                    </div>
                                </div>
                            </div>
                        {% endfor %}
                    </div>
                    <div id="ascent" class="container tab-pane fade"><br>
                        {% for sport, top_award in top_ascent_awards.items %}
                            <div class="card">
                                <div class="card-header">
                                    <h4 class="card-title">{{ sport }}&nbsp;&nbsp;<a href="/sport/{{ sport.slug }}"><i class="fas fa-{{ sport.icon }}" style="color: {{ sport.color }};"></i></a></h4>
                                </div>
                                <div class="card-body">
                                    <div class="table-responsive">
                                        {% include "awards/ascent_table.html" %}
                                    </div>
                                </div>
                            </div>
                        {% endfor %}
                    </div>
                </div>
                <p>{{ info_text.general }}</p>
            </div>
        </div>
    </div>
</div>
{% endblock %}
