{% extends 'lib/base.html' %}
{% load static %}
{% block body %}
<div class="row">
    <div class="col-md-6 mr-auto ml-auto">
        <div class="card">
            <div class="card-body">
                <p>Are you sure you want to delete '{{ activity }}' Activity?</p>
                <br>
                {% if activity.trace_file %}
                    <div class="alert alert-danger">
                        <strong>
                            <i class="fas fa-exclamation-triangle"></i>&nbsp;&nbsp;Warning&nbsp;&nbsp;<i
                                class="fas fa-exclamation-triangle"></i>
                        </strong>
                        <br>
                        This will also delete the trace file of this activity located at:
                        <br>
                        <code>{{ activity.trace_file.path_to_file }}</code>
                    </div>
                {% endif %}

                <form method="post">{% csrf_token %}
                    <button class="float-left btn btn-danger btn-space" type="submit">
                        <i class="fas fa-trash-alt"></i>&nbsp;&nbsp;Delete
                    </button>
                    <a href="/activity/{{ activity.id }}" class="btn btn-outline-secondary">Cancel</a>
                    <div class="clearfix"></div>
                </form>
            </div>
        </div>
    </div>
</div>
{% endblock %}