# Generated by Django 3.1.5 on 2021-01-30 12:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("wkz", "0001_squashed_0014_auto_20210112_1924"),
    ]

    operations = [
        migrations.AddField(
            model_name="activity",
            name="evaluates_for_awards",
            field=models.BooleanField(default=True, verbose_name="Consider this Activity for Awards:"),
        ),
        migrations.AddField(
            model_name="sport",
            name="evaluates_for_awards",
            field=models.BooleanField(default=True, verbose_name="Consider Awards for this Sport:"),
        ),
        migrations.AlterField(
            model_name="bestsection",
            name="section_distance",
            field=models.IntegerField(),
        ),
        migrations.AlterField(
            model_name="traces",
            name="avg_temperature",
            field=models.FloatField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="traces",
            name="max_temperature",
            field=models.FloatField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="traces",
            name="min_temperature",
            field=models.FloatField(blank=True, null=True),
        ),
        migrations.DeleteModel(
            name="BestSectionTopScores",
        ),
    ]
