<!--
=========================================================
* Paper Dashboard 2 PRO - v2.1.1
=========================================================

* Product Page: https://www.creative-tim.com/product/paper-dashboard-2-pro
* Copyright 2020 Creative Tim (https://www.creative-tim.com)

Coded by www.creative-tim.com

 =========================================================

* The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
-->
<!DOCTYPE html>
<html lang="en">
{% load static %}
{% load filters %}

<head>
    <meta charset="utf-8" />
    <link rel="icon" type="image/ico" href="{% static 'img/favicon.ico' %}">
    <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1"/>

    <title>
        {{ page_name }} | Workoutizer
    </title>

    <meta content='width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=0, shrink-to-fit=no' name='viewport' />
    
    <!-- Fonts and icons -->
    <link href="https://fonts.googleapis.com/css?family=Montserrat:400,700,200" rel="stylesheet" />

    <!-- required for form-check-sign -->
    <link href="https://maxcdn.bootstrapcdn.com/font-awesome/latest/css/font-awesome.min.css" rel="stylesheet">

    <!-- Font Awesome Icons -->
    <link rel="stylesheet" href="https://use.fontawesome.com/releases/v5.6.3/css/all.css"
          integrity="sha384-UHRtZLI+pbxtHCWp1t77Bi1L4ZtiqrqD80Kn4Z8NTSRyMA2Fd33n5dQ8lWUE00s/"
          crossorigin="anonymous">

    <!-- CSS Files -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@4.6.0/dist/css/bootstrap.min.css"
        integrity="sha384-B0vP5xmATw1+K9KRQjQERJvTumQW0nPEzvF6L/Z6nronJ3oUOFUFpCjEUQouq2+l"
        crossorigin="anonymous">
    <link href="{% static 'css/paper-dashboard.css' %}" rel="stylesheet" />

    <!-- leaflet -->
    <link rel="stylesheet" href="https://unpkg.com/leaflet@1.7.1/dist/leaflet.css"
        integrity="sha512-xodZBNTC5n17Xt2atTPuE1HxjVMSvLVW9ocqUKLsCC5CXdbqCmblAshOMAS6/keqq/sMZMZ19scR4PsZChSR7A=="
        crossorigin=""/>
    <script src="https://unpkg.com/leaflet@1.7.1/dist/leaflet.js"
        integrity="sha512-XQoYMqMTK8LvdxXYG3nZ448hOEQiglfqkJs1NOQV44cWnUrBc8PkAOcXy20w0vlaXaVUearIOBhiXZ5V3ynxwA=="
        crossorigin=""></script>

    <!-- server sent events via django_eventstream -->
    {% include "lib/server_sent_events.html" %}
</head>

<body onload="start_sse();">
    <div class="wrapper ">
        {% include "lib/sidebar.html" %}
        <div class="main-panel">
            {% include "lib/navbar.html" %}
            <div class="content">
                {% include "lib/messages.html" %}
                {% block body %}
                    // content will be here
                {% endblock %}
            </div>
            {% include "lib/footer.html" %}
        </div>
    </div>

    <!-- htmx -->
    <script src="https://unpkg.com/htmx.org@1.2.0"
        integrity="sha384-DK9cslo5RE1LAnW8sCw7cSHU2nlzkXfo2NmCQD+4disC90ClC1ywgMbijNPxFVki"
        crossorigin="anonymous"></script>
    <!-- bootstrap.js and popper: needed for toggling the sidebar -->
    <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"
        integrity="sha384-DfXdz2htPH0lsSSs5nCTpuj/zy4C+OGpamoFVy38MVBnE+IbbVYUew+OrCXaRkfj"
        crossorigin="anonymous"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@4.6.0/dist/js/bootstrap.bundle.min.js"
        integrity="sha384-Piv4xVNRyMGpqkS2by6br4gNJ7DXjqk09RmUpJ8jgGtD7zP9yug3goQfGII0yAns"
        crossorigin="anonymous"></script>

    <script src="{% static 'js/plugins/moment.min.js' %}"></script>
    <!--  Plugin for the DateTimePicker, full documentation here: https://eonasdan.github.io/bootstrap-datetimepicker/ -->
    <script src="{% static 'js/plugins/bootstrap-datetimepicker.js' %}"></script>
    <!-- Control Center for Now Ui Dashboard: parallax effects, scripts for the example pages etc -->
    <script src="{% static 'js/paper-dashboard.min.js' %}" type="text/javascript"></script>
    <!--  Notifications Plugin    -->
    <script src="{% static  'js/plugins/bootstrap-notify.js' %}"></script>
    <script src="{% static 'js/custom.js' %}"></script>
    <script>
    $(document).ready(function() {
        // initialise Datetimepicker
        demo.initDateTimePicker();
    });
    </script>
    {% include "lib/keyboard_shortcuts.html" %}
</body>

</html>
