# Generated by Django 3.2 on 2021-04-30 14:33

import datetime

import colorfield.fields
import django.db.models.deletion
import django.utils.timezone
from django.db import migrations, models

import wkz.models


class Migration(migrations.Migration):

    dependencies = [
        ("wkz", "0006_auto_20210321_1812"),
    ]

    operations = [
        migrations.AlterField(
            model_name="activity",
            name="date",
            field=models.DateTimeField(default=django.utils.timezone.now, verbose_name="Date"),
        ),
        migrations.AlterField(
            model_name="activity",
            name="description",
            field=models.CharField(blank=True, max_length=600, null=True, verbose_name="Description"),
        ),
        migrations.AlterField(
            model_name="activity",
            name="distance",
            field=models.FloatField(blank=True, default=0, null=True, verbose_name="Distance"),
        ),
        migrations.AlterField(
            model_name="activity",
            name="duration",
            field=models.DurationField(default=datetime.timedelta(seconds=1800), verbose_name="Duration"),
        ),
        migrations.AlterField(
            model_name="activity",
            name="evaluates_for_awards",
            field=models.BooleanField(default=True, verbose_name="Consider Activity for Awards"),
        ),
        migrations.AlterField(
            model_name="activity",
            name="id",
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID"),
        ),
        migrations.AlterField(
            model_name="activity",
            name="is_demo_activity",
            field=models.BooleanField(default=False, verbose_name="Is this a Demo Activity"),
        ),
        migrations.AlterField(
            model_name="activity",
            name="name",
            field=models.CharField(default="unknown", max_length=200, verbose_name="Activity Name"),
        ),
        migrations.AlterField(
            model_name="activity",
            name="sport",
            field=models.ForeignKey(
                default=wkz.models.default_sport,
                on_delete=django.db.models.deletion.SET_DEFAULT,
                to="wkz.sport",
                verbose_name="Sport",
            ),
        ),
        migrations.AlterField(
            model_name="bestsection",
            name="id",
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID"),
        ),
        migrations.AlterField(
            model_name="lap",
            name="id",
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID"),
        ),
        migrations.AlterField(
            model_name="lap",
            name="label",
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name="Label"),
        ),
        migrations.AlterField(
            model_name="settings",
            name="delete_files_after_import",
            field=models.BooleanField(default=False, verbose_name="Delete fit Files after Copying "),
        ),
        migrations.AlterField(
            model_name="settings",
            name="id",
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID"),
        ),
        migrations.AlterField(
            model_name="settings",
            name="path_to_garmin_device",
            field=models.CharField(default="/run/user/1000/gvfs/", max_length=120, verbose_name="Path to Garmin Device"),
        ),
        migrations.AlterField(
            model_name="settings",
            name="path_to_trace_dir",
            field=models.CharField(
                default="/workspaces/workoutizer/tracks", max_length=120, verbose_name="Path to Traces Directory"
            ),
        ),
        migrations.AlterField(
            model_name="sport",
            name="color",
            field=colorfield.fields.ColorField(default="#42FF71", max_length=18, verbose_name="Color"),
        ),
        migrations.AlterField(
            model_name="sport",
            name="evaluates_for_awards",
            field=models.BooleanField(default=True, verbose_name="Consider Sport for Awards"),
        ),
        migrations.AlterField(
            model_name="sport",
            name="icon",
            field=models.CharField(max_length=24, verbose_name="Icon"),
        ),
        migrations.AlterField(
            model_name="sport",
            name="id",
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID"),
        ),
        migrations.AlterField(
            model_name="sport",
            name="name",
            field=models.CharField(max_length=24, unique=True, verbose_name="Sport Name"),
        ),
        migrations.AlterField(
            model_name="traces",
            name="id",
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID"),
        ),
    ]
