{% load filters %}

<div class="row">

    {% comment %} Date {% endcomment %}
    <div class="col-lg-3 col-md-6 col-sm-6">
        <div class="card card-stats">
            <div class="card-body ">
                <div class="row">
                    <div class="col-5 col-md-4">
                        <div class="icon-big text-center icon-warning">
                            <i class="fa fa-calendar-alt text-warning"></i>
                        </div>
                    </div>
                    <div class="col-7 col-md-8">
                        <div class="numbers" data-toggle="tooltip" data-placement="bottom" title="{{ activity.date|date:"Y-m-d H:i" }}">
                            <p class="card-category">Date</p>
                            <p class="card-title">{{ activity.date|date:"d. M y" }}</p>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    {% comment %} Distance {% endcomment %}
    <div class="col-lg-3 col-md-6 col-sm-6">
        <div class="card card-stats">
            <div class="card-body ">
                <div class="row">
                    <div class="col-5 col-md-4">
                        <div class="icon-big text-center icon-warning">
                            <i class="fa fa-road text-success"></i>
                        </div>
                    </div>
                    <div class="col-7 col-md-8">
                        <div class="numbers">
                            <p class="card-category">Distance</p>
                            <p class="card-title">{{ activity.distance }} km<p>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    {% comment %} Duration {% endcomment %}
    <div class="col-lg-3 col-md-6 col-sm-6">
        <div class="card card-stats">
            <div class="card-body ">
                <div class="row">
                    <div class="col-5 col-md-4">
                        <div class="icon-big text-center icon-warning">
                            <i class="fas fa-history text-danger"></i>
                        </div>
                    </div>
                    <div class="col-7 col-md-8">
                        <div class="numbers">
                            <p class="card-category">Duration</p>
                            <p class="card-title">{{ activity.duration|duration }}<p>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    {% comment %} Calories {% endcomment %}
    <div class="col-lg-3 col-md-6 col-sm-6">
        <div class="card card-stats">
            <div class="card-body ">
                <div class="row">
                    <div class="col-5 col-md-4">
                        <div class="icon-big text-center icon-warning">
                            <i class="fa fa-fire text-primary"></i>
                        </div>
                    </div>
                    <div class="col-7 col-md-8">
                        <div class="numbers">
                            <p class="card-category">Calories</p>
                            <p class="card-title">
                                {% if activity.trace_file.calories %}
                                    {{ activity.trace_file.calories }} kcal
                                {% else %}
                                    - kcal
                                {% endif %}
                            <p>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

</div>