from django.contrib import admin

from wkz import models

admin.site.register(models.Sport)
admin.site.register(models.Activity)
admin.site.register(models.Settings)
admin.site.register(models.Traces)
admin.site.register(models.Lap)
admin.site.register(models.BestSection)
