# Generated by Django 3.1.6 on 2021-02-18 21:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("wkz", "0002_auto_20210130_1351"),
    ]

    operations = [
        migrations.AlterField(
            model_name="settings",
            name="number_of_days",
            field=models.IntegerField(
                choices=[
                    (9999, "all"),
                    (1095, "last 3 years"),
                    (730, "last 2 years"),
                    (365, "last year"),
                    (180, "last 180 days"),
                    (90, "last 90 days"),
                    (30, "last 30 days"),
                    (10, "last 10 days"),
                ],
                default=30,
            ),
        ),
    ]
